summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--firmware/lib/vboot_api_kernel.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/firmware/lib/vboot_api_kernel.c b/firmware/lib/vboot_api_kernel.c
index a013c8f2..5ef78027 100644
--- a/firmware/lib/vboot_api_kernel.c
+++ b/firmware/lib/vboot_api_kernel.c
@@ -198,8 +198,10 @@ VbError_t VbBootRecovery(VbCommonParams* cparams, LoadKernelParams* p) {
VBDEBUG(("VbBootRecovery() start\n"));
- /* If dev mode switch is off, require removal of all external media. */
- if (!(shared->flags & VBSD_BOOT_DEV_SWITCH_ON)) {
+ /* If the dev-mode switch is off and the user didn't press the recovery
+ * button, require removal of all external media. */
+ if (!(shared->flags & VBSD_BOOT_DEV_SWITCH_ON) &&
+ (VBNV_RECOVERY_RO_MANUAL != shared->recovery_reason)) {
VbDiskInfo* disk_info = NULL;
uint32_t disk_count = 0;